View source: R/VariableSelectionNew.R
| FS_barplot | R Documentation |
Displays retained features for different values of alpha in a bar plot.
FS_barplot(
data = NULL,
grid.alpha = seq(0.01, 0.99, by = 0.01),
missing = FALSE,
pv_adj = "none",
smooth.tol = 10^-12,
method = "c"
)
data |
A data frame. Values of type 'numeric' or 'integer' are treated as numerical. |
grid.alpha |
A vector of alpha values to be plotted, default = seq(0.01,0.99,by=0.01). |
missing |
Pairwise complete by default, set to TRUE for complete deletion. |
pv_adj |
Correction method for p-value, "none" by default. For options see p.adjust. |
smooth.tol |
Minimum acceptable eigenvalue for the smoothing, default 10^-12. |
method |
Algorithm used. c (cell-wise) by default, r (row-wise) as the alternative. |
Displays a bar plot depicting which features are selected at each value of alpha (multiplied by 100) and a list with elements:
survivors |
Vector depicting how many alphas a variable is selected for |
data_names |
Vector depicting the corresponding names of the features |
Tortora C., Madhvani S., Punzo A. (2025). Designing unsupervised mixed-type feature selection techniques using the heterogeneous correlation matrix. International Statistical Review. https://doi.org/10.1111/insr.70016
data(ESI)
data=ESI[,-c(1,3,4,6,9)]##removing categorical features
FS_barplot(data, pv_adj='BH') #using BH adkustment for the p-values
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.