View source: R/VariableSelectionNew.R
| HCPM | R Documentation |
Extends the traditional correlation matrix (between numerical data) to also include binary and ordinal categorical data and computes the p-values for the tests of uncorrelation.
HCPM(data = NULL)
data |
A data frame. Values of type 'numeric' or 'integer' are treated as numerical. |
A list with with elements:
cor_mat |
An |
p_value |
An |
Tortora C., Madhvani S., Punzo A. (2025). Designing unsupervised mixed-type feature selection techniques using the heterogeneous correlation matrix. International Statistical Review. https://doi.org/10.1111/insr.70016
data(ESI)
data=ESI[,-c(1,3,4,6,9)]##removing categorical features
HCPM(data)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.